@@ -7,8 +7,8 @@ from nginx_analysis.analysis import (
     get_unique_directives,
     parse_config,
 )
-from nginx_analysis.dataclasses import AllFilter
-from nginx_analysis.filter import args_to_filter, logline_to_filters
+from nginx_analysis.dataclasses import AllFilter, AnyFilter
+from nginx_analysis.filter import args_to_filter, logline_to_filter
 from nginx_analysis.input import get_args, get_loglines, setup_logger
 from nginx_analysis.log import parse_logline
 from nginx_analysis.output import render_directive_matches
@@ -22,11 +22,16 @@ def main():
     root_config = parse_config(args.file)
     filters = AllFilter()
     if "logs" in args:
+        # We combine all logline filters into an AnyFilter
+        # to match directives that match any of the loglines
+        logline_filters = []
         for line in get_loglines(args.logs):
             parsed_line = parse_logline(root_config, line)
             logger.debug(parsed_line)
-            log_filters = logline_to_filters(parsed_line)
-            filters += log_filters
+            log_filter = logline_to_filter(parsed_line)
+            logline_filters.append(log_filter)
+        if logline_filters:
+            filters += AnyFilter(filters=logline_filters)
 
     if "directives" in args:
         directives = get_unique_directives(root_config)
